@@ -3,6 +3,8 @@
 use std::path::PathBuf;
 use std::process::Command;
 
+use path_clean::PathClean;
+
 use crate::config::CrateConfig;
 use crate::core::Link;
 use crate::core::RswInfo;
@@ -29,12 +31,17 @@ impl Build {
         let name = &config.name;
         let root = config.root.as_ref().unwrap();
         let out_dir = config.out_dir.as_ref().unwrap();
-        let crate_root = PathBuf::from(root)
-            .join(name)
-            .canonicalize().unwrap();
+        let crate_root = PathBuf::from(root).join(name).clean();
         let build_name = crate_root.to_string_lossy().to_string();
         let target = config.target.as_ref().unwrap();
-        let mut args = vec!["build", &build_name, "--out-dir", out_dir, "--target", target];
+        let mut args = vec![
+            "build",
+            &build_name,
+            "--out-dir",
+            out_dir,
+            "--target",
+            target,
+        ];
 
         // profile
         let mut profile = config.build.as_ref().unwrap().profile.as_ref().unwrap();
@@ -90,16 +97,14 @@ impl Build {
                     is_ok = false;
                 }
             }
-            None => {}
+            _ => {}
         }
 
         if config.link.unwrap() {
             let cli = &self.cli;
             Link::new(
                 cli.into(),
-                PathBuf::from(root)
-                    .join(name)
-                    .join(out_dir),
+                PathBuf::from(root).join(name).join(out_dir),
                 name.to_string(),
             )
             .init();
